<?php
namespace Neuron\Person\Controller;

use Neuron\Person\Attribute as AttrModel;

class Attribute extends \Neuron\Person\Controller{

	protected function getView($name, $variables = array()) {

		/* default layout & view prefix */
		$layout = 'neuron/person/layout/form';
		$prefix = 'neuron/person/attribute';

		/* libraries */
		if(! class_exists('Neuron\Application\Framework\Entity')) {
			$this->using('jquery', null)
                ->using('popper', null)
                ->using('bootstrap', null)
                ->using('fontawesome', null);
		}

		/* get layout n view prefix from config */
		$config = $this->getConfig();
		if (isset($config['person'])) {
			$config = $config['person'];
			$layout = isset($config['formlayout']) ? $config['formlayout'] : $layout;
			$prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
		}


		$this->using('nAlert',999999);

		/* set layout and view */
		$libs['Contact'] = class_exists('Neuron\Contact\Controller\Contact');
		$libs['Organization'] = class_exists('Neuron\Organization\Controller\Organization');
		$libs['Payroll'] = class_exists('Neuron\Payroll\Controller\Payroll');
		$variables['libs'] = $libs;

		$this->layout($layout);
		$view = new \Zend\View\Model\ViewModel($variables);
		$view->setTemplate($prefix . '/' . strtolower($name));

		return $view;
	}

	public function indexAction(){
		$layout = $this->layout();
		if(class_exists('Neuron\Employee\Entity')){
			$layout->setVariables(['previous' => '<a href="'.$this->getPublicURL().'/person/index/manage">Manage Employee</a>']);
			$layout->setVariables(['current' => 'Employee Attribute']);
		}else{
			$layout->setVariables(['previous' => '<a href="'.$this->getPublicURL().'/person/index/manage">Manage Person</a>']);
			$layout->setVariables(['current' => 'Person Attribute']);
		}
		$this->using('p-loading',20);
		$post 			= $this->getPostParams();
		$person_id 	= $post['person_id'];
		return $this->getView('emp-attribute',get_defined_vars());	
	}

	public function editAttributeAction(){
		$layout = $this->layout();
		if(class_exists('Neuron\Employee\Entity')){
			$layout->setVariables(['previous' => '<a href="'.$this->getPublicURL().'/person/index/manage">Manage Employee</a>']);
			$layout->setVariables(['current' => 'Employee Attribute']);
		}else{
			$layout->setVariables(['previous' => '<a href="'.$this->getPublicURL().'/person/index/manage">Manage Person</a>']);
			$layout->setVariables(['current' => 'Person Attribute']);
		}
		$this->using('generic', 22);
		$post 			= $this->getPostParams();
		$person_id 	= $post['person_id'];
		return $this->getView('edit-attribute',get_defined_vars());
	}

	public function saveAction(){
		$file 	= $this->getRequest()->getFiles();
		$post = $this->getREST()->getParameters();
		$attributeFiles = isset($file['image']) ? $file['image'] : array();

	    if(empty($post)){
			$post = $this->getPostParams();
			$dataAttribute 	= json_decode(@$post['attribute'],true);
			$postAttr = array();
			foreach ($dataAttribute as $attr) {
				$postAttr[$attr['name']] = array(
					'value' 	=> $attr['value'],
				);
			}
			$postAttr['person_id'] = $post['person_id'];
			$post 	= $postAttr;
	    }else{
		    $session 	= $this->getSession();
	        $sessid 	= $session->getId();

	        if(!isset($post['token']) || empty($post['token'])){
	        	$result =  new \Neuron\Generic\Result(0,parent::CODE_FIELD_REQUIRED,$this->translate('Token required!'));
	        	return $this->getREST()->getResponse($result);
	        }else{
	        	$token = $post['token'];
	        }


	        if ($token != $sessid) {
	        	$result =  new \Neuron\Generic\Result(0,parent::CODE_UNAUTHORIZED,$this->translate('Invalid token!'));
	            return $this->getREST()->getResponse($result);
	        }
		}

		$attrModel	= new AttrModel(AttrModel\Storage::factory($this->getDb(),$this->getConfig()));
		$session 	= $this->getSession();
		$result 	= $attrModel->save($post,$session->owner(),$attributeFiles);
		
		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 

		$logparam['subject'] = 'PERSON SAVE ATTRIBUTE';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['data1'] = $result->data;
		$logparam['description'] = 'Log proses person save attribute';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);

		$this->writeLogAction($logparam);
		
		return $this->getREST()->getResponse($result);
	}

	public function loadSavedAttributeAction(){
		$post = $this->getREST()->getParameters();
	    if(empty($post)){
	      $post = $this->getPostParams();
	    }

		$attrModel 	= new AttrModel(AttrModel\Storage::factory($this->getDb(),$this->getConfig()));
		$result 	= $attrModel->loadSavedAttribute($post);
		$resultData = $result->data;

		$data 		= [];
		foreach($resultData as $row){
			$storage = \Neuron\Document\Entity\Storage::factory($this->getDb(), $this->getConfig());
			$model = new \Neuron\Document\Entity($storage);

			$dataAudit = $model->loadAudit('document_id', $row['document_id']);
			$dataDocument = $model->load($row['document_id']);
			$dataFile = $model->loadFile('document_id', $row['document_id']);
			$arrfile = [];
			if($dataFile){
				foreach ($dataFile as $file) {
					if(file_exists(getcwd() .$file['file_dir'].'/'. $file['file_name'])){
						$arrfile[] = $file;
					}
				}
			}
			$dataOwner = $model->loadOwner('document_id', $row['document_id']);
			$row['document'] = array('dataFile'=>$arrfile, 'dataAudit'=>$dataAudit, 'dataOwner'=>$dataOwner);
			$data[] = $row;
		}

		$result->data 	= $data;

		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 

		$logparam['subject'] = 'PERSON LOADSAVEDATTRIBUTE';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['data1'] = $result->data;
		$logparam['description'] = 'Log proses person loadSavedAttribute';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);

		$this->writeLogAction($logparam);
		
		return $this->getREST()->getResponse($result);
	}

	public function endDocumentAction(){
		$result 				= new \Neuron\Generic\Result();

		$post 					= $this->getREST()->getParameters();
		$storageDocumentEntity 	= \Neuron\Document\Entity\Storage::factory(
			$this->getDb(),
			$this->getConfig()
		);

		$session	= $this->getSession();
		$sessOwner	= $session->owner();

		$document_id 			= $post['document_id'];
		$attribute_id 			= $post['attribute_id'];

		// Delete document ID
		$attribute 			= new AttrModel(
			AttrModel\Storage::factory(
				$this->getDb(),
				$this->getConfig()
			)
		);
		$attribute->loadRow($attribute_id);
		$attribute->document_id 	= null;
		$saveAttribute 				= $attribute->_save(true);
		
		// Edit end_dtm document;
		$documentEntity 	= new \Neuron\Document\Entity($storageDocumentEntity);
		$dataFile 		= $documentEntity->loadFile('document_id',$document_id);
		$documentEntity->load($document_id);
		$documentEntity->document_end_dtm = $storageDocumentEntity->now();

		if($documentEntity->save(true)){
			// terminate document files;
			$dataFile 		= $documentEntity->loadFile('document_id',$document_id);
			
			foreach($dataFile as $df){
				$documentFile 	= new \Neuron\Document\Files(
					\Neuron\Document\Files\Storage::factory(
						$this->getDb(),
						$this->getConfig()
					)
				);
				$documentFile->push($df);
				$documentFile->document_file_status = 0;
				$documentFile->save(true);
			}

			// Create audit terminate;
			$documentAudit = new \Neuron\Document\Audit(
				\Neuron\Document\Audit\Storage::factory(
					$this->getDb(),
					$this->getConfig()
				)
			);
			$dataAudit 		= array(
				"document_id"		=> $document_id,
				"user_id"			=> $sessOwner,
				"audit_type_id"		=> 5, #Audit type terminate
				"audit_dtm"			=> $storageDocumentEntity->now(),
				"notes"				=> "Document terminated",
			);
			$documentAudit->push($dataAudit);
			if(!$documentAudit->save(false)){
				$result->code 	= 2;
				$result->info 	= "Failed saving audit";
			}

			
		}else{
			$result->code 		= 1;
			$result->info 		= "Failed saving document";
		}

		$result->info = $this->translate($result->info);
		return $this->getREST()->getResponse($result);


	}

	public function multiSaveAction(){
		$post 	= $this->getRequest()->getPost();
		$files 	= $this->getRequest()->getFiles();
		$dataAttributes 	= json_decode($post['attribute'],true);

		$session 	= $this->getSession();
		$sessOwner 	= $session->owner();

		$attributeStorage 	= \Neuron\Person\v2\Attribute\Storage::factory(
			$this->getDb(),
			$this->getConfig()
		);
		$attributes = new \Neuron\Person\v2\Attributes($attributeStorage);
		foreach($dataAttributes as $data){
			$attribute 	= new \Neuron\Person\v2\Attribute($attributeStorage,array(
				"attr_code" => $data['name'],
				"person_id" => $post['person_id'],
				"attr_value" => $data['value'],
				"start_date" => $attributeStorage->now(),
				"update_dtm" => $attributeStorage->now(),
				"tmp_file" => isset($files['image'][$data['name']]) ? $files['image'][$data['name']] : null,
				'update_by' => $sessOwner
			));
			$attributes->add($attribute);
		}
		$result 	= $attributes->save();
		return $this->getREST()->getResponse($result);
	}
}