<?php
namespace Neuron\Person\Controller;

class Family extends \Neuron\Person\Controller {

    protected function getView($name, $variables = array()){
        /* default layout & view prefix */
        $layout = 'neuron/person/layout/form';
        $prefix = 'neuron/person/family';

        /* libraries */
        $this->using('jquery', null, false)
        ->using('bootstrap', null)
        ->using('font-awesome', null)
        ->using('bootbox');

        /* get layout n view prefix from config */
        $config = $this->getConfig();
        if (isset($config['task'])) {
        $config = $config['task'];
        $layout = isset($config['formlayout']) ? $config['formlayout'] : $layout;
        $prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
        }


        // Script FCM
            $config = $this->getConfig();
            $opt = new Notification\FCM\Options();
            $opt->push($config['notification']['fcm']);
            
            $template = new Notification\Template(Notification\Template\Storage::factory($this->getDb(), $this->getConfig()));
            
            $fcm = new Notification\FCM(
                Notification\Email\Storage::factory($this->getDb(), $this->getConfig()),
                $template,
                $opt
            );
            
            $id_user = $this->userID();
            $script = $fcm->listen('firebaseHandler', $id_user, $this->getPublicUrl());
            
        $variables['script'] = $script;

        /* set layout and view */
        $this->layout($layout);

        $view = new \Zend\View\Model\ViewModel($variables);
        $view->setTemplate($prefix . '/' . strtolower($name));

        return $view;
    }

    protected function getViewPartial($name, $variables = array()){
        $prefix = 'neuron/person/family';
        $config = $this->getConfig();
        if (isset($config['task'])) {
            $config = $config['task'];
            $prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
        }

        $view = new \Zend\View\Model\ViewModel($variables);
        $view->setTemplate($prefix . '/' . strtolower($name)); // path to phtml file under view folder
        return $view;
    }

    // Moved to /controller/widget/family
    public function formAction()
    {
        $post = $this->getPostParams();
        $id = $post['id'];
        $person_id = $post['person_id'];
        $famdata = array();
        $title = "Create Family";

        $storage = \Neuron\Person\Parameter\Storage::factory($this->getDb(), $this->getConfig());
        $cpar = new \Neuron\Person\Parameters($storage);

        $post = $this->getPostParams();
        $arr = $cpar->listparam($post['param_ref_name']);
        $relation = array();

        if ($arr) {
            foreach ($arr as $data) {
                if($data['param_ref_name'] == 'FAMILY_RELATION'){
                    array_push($relation, $data);
                }
            }
        }
        
        if($id){
            $storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
            $cfam = new \Neuron\Person\Family($storage);
            $title = "Edit Family";
            if ($cfam->load($id))  {
                $famdata = $cfam->pull();
            }
        }
        return $this->getViewPartial('crud', get_defined_vars());
    }
    public function listAction() {
        $storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
        $cfam = new \Neuron\Person\Families($storage);

        $post = $this->getPostParams();
        $arr = $cfam->listdata($post);

        $arrRelation = array();
        $dataRelation = $cfam->loadRelation();
        // print_r(''); die();
        if($dataRelation){
            foreach ($dataRelation as $relation) {
                array_push($arrRelation, $relation);
            }
        }

        // print_r($arrRelation); die();
        // $arr['relation'] = $arrRelation;

        echo json_encode($arr);
        return $this->getResponse();
    }

    public function loadAction() {
        $storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
        $cexp = new \Neuron\Person\Family($storage);

        $post = $this->getPostParams();
        if (!$cexp->load($post['family_id']))  {
            echo json_encode(array('success' => false, 'data' => array()));
            return $this->getResponse();
        }

        $expdata = $cexp->pull();

        echo json_encode(array('success' => true, 'data' => $expdata));
        return $this->getResponse();
    }

    public function saveAction() {
        $storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
        
        $post = $this->getPostParams();
        if (!empty($post['family_id'])) {
            $update = true;
        } else {
            $update = false;
            $post['family_id'] = null;
        }
        $post['birth_date'] = $post['birth_date_fa'];
        $post['start_date'] = date("Y-m-d");
        
        $cexp = new \Neuron\Person\Family($storage, $post);
        $retval = $cexp->save($update);
		
		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$logparam['subject'] = 'PERSON SAVE FAMILY';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['data1'] = $retval;
		$logparam['description'] = 'Log proses person save family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($retval);

		$this->writeLogAction($logparam);
		
        echo json_encode(array('success' => $retval));
        return $this->getResponse();
    }

    public function deleteAction() {
        $storage = \Neuron\Person\Family\Storage::factory($this->getDb(), $this->getConfig());
        $cexp = new \Neuron\Person\Family($storage);

        $post = $this->getPostParams();

        $retval = $cexp->delete($post['family_id']);
        $success = false;
        if ($retval) $success = true;
		
		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$logparam['subject'] = 'PERSON DELETE FAMILY';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['data1'] = $retval;
		$logparam['description'] = 'Log proses person delete family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($retval);

		$this->writeLogAction($logparam);
		
        echo json_encode(array('success' => $success));
        return $this->getResponse();
    }

}
