<?php

namespace Neuron\Person;

use Neuron\Generic\Result;
use Neuron\Generic\Set;
use Nueron\Person\Family;

class Families extends Set
{

	protected $_storage;

	public function __construct(\Neuron\Person\Family\Storage\Skeleton $storage)
	{

		$this->_storage = $storage;
	}

	public function load($ids = '', $mode = Family\Storage::LIST_ALL, $params = array()){
        $result = new Result();
        try {
            /* clear list */
            $this->clear();

            if ($rs = $this->_storage->loadList($ids, $mode, $params)) {
                if ($rows = $rs->list) {
                    $rows = $rs->list;
                    $list = [];
                    foreach ($rows as $row) {
                        /* for issue oracle */
                        $row = array_change_key_case($row);
                        unset($row['b_rownum']);
                        /* new user */
                        $model = new Family($this->_storage);
                        $model->push($row);
                        $this->add($model);
                        $list[] = $row;
                    }

                    $result->data = [
                        'pager' => $rs->pager,
                        'list' => $list,
                        'countTotal' => $rs->countTotal,
                    ];
                } else {
                    $result->code = 2;
                    $result->info = 'load_none';
                }
            } else {
                $result->code = 1;
                $result->info = 'load_not_found';
            }

            return $result;
        } catch (Throwable $throwable) {
            error_log('Error at ' . $throwable->getFile() . ' line ' . $throwable->getLine() . ': ' . $throwable->getMessage());
            $result->code = 500;
            $result->info = 'error';
            return $result;
        }
    }
}