<?php
namespace Neuron\Person\v2;

use Neuron\Generic\Result;
use Neuron\Generic\Set;
use Throwable;
use Neuron\Person\V2\Attribute;

class Attributes extends Set
{
    protected $_storage;

    public function __construct(Attribute\Storage\Skeleton $skeleton)
    {
        $this->_storage = $skeleton;
    }

    public function load($ids = '', $mode = Attribute\Storage::LIST_ALL, $params = array()){
        $result = new Result();
        try {
            /* clear list */
            $this->clear();

            if ($rs = $this->_storage->loadList($ids, $mode, $params)) {
                if ($rows = $rs->list) {
                    $rows = $rs->list;
                    $list = [];
                    foreach ($rows as $row) {
                        /* for issue oracle */
                        $row = array_change_key_case($row);
                        unset($row['b_rownum']);
                        /* new user */
                        $attribute = new Attribute($this->_storage);
                        $attribute->push($row);
                        $this->add($model);
                        $list[] = $row;
                    }

                    $result->data = [
                        'pager' => $rs->pager,
                        'list' => $list,
                        'countTotal' => $rs->countTotal,
                    ];
                } else {
                    $result->code = 2;
                    $result->info = 'load_none';
                }
            } else {
                $result->code = 1;
                $result->info = 'load_not_found';
            }

            return $result;
        } catch (Throwable $throwable) {
            error_log('Error at ' . $throwable->getFile() . ' line ' . $throwable->getLine() . ': ' . $throwable->getMessage());
            $result->code = 500;
            $result->info = 'error';
            return $result;
        }
    }

    public function save(){
        $result     = new Result();
        $saveResult = [];
        
        $success    = [];
        $error      = [];

        foreach($this as $attribute){
            $saveAttribute = $attribute->saveEx(
                $attribute->pull(3)
            );
            if($saveAttribute->code == 0){
                $success[] = $saveAttribute;
            }else{
                $error[]    = $saveAttribute;
            }
        }
        $result->data = array(
            'success'   =>$success,
            'error'     => $error
        );
        
        return $result;
        
    }
}
